==> apache-camel-3.5.0-src.zip: apache-camel-3.5.0/components/components-init-work-in-progress.md <==
# This is used to track the work of [CAMEL-14805 ](https://issues.apache.org/jira/browse/CAMEL-14805) and [CAMEL-15176](https://issues.apache.org/jira/browse/CAMEL-15176)

| component | status | reason |
|   ---- | ---- | ---- |
|camel-activemq|DONE| |
|camel-ahc|REJECT|create thread pool|
|camel-ahc-ws|REJECT|open network connection|
|camel-amqp|DONE| |
|camel-any23|DONE| |
|camel-apns|REJECT|add the consumer should be in doStart |
|camel-arangodb|REJECT|open network connection to resolve host server|
|camel-as2|REJECT| |
|camel-asn1|DONE| |
|camel-asterisk|DONE| |
|camel-atmos| | |
|camel-atmosphere-websocket|DONE| |
|camel-atom|DONE| |
|camel-atomix|DONE| |
|camel-attachments|DONE| |
|camel-avro|DONE| |
|camel-avro-rpc|REJECT|start a server|
|camel-aws|DONE| |
|camel-aws2-athena|DONE| |
|camel-aws2-cw|DONE| |
|camel-aws2-ddb|REJECT| |
|camel-aws2-ec2|REJECT| |
|camel-aws2-ecs|REJECT| |
|camel-aws2-eks|REJECT| |
|camel-aws2-iam|REJECT| |
|camel-aws2-kinesis|REJECT| |
|camel-aws2-kms|REJECT| |
|camel-aws2-lambda|REJECT| |
|camel-aws2-mq|REJECT| |
|camel-aws2-msk|REJECT| |
|camel-aws2-s3|REJECT| |
|camel-aws2-ses|REJECT| |
|camel-aws2-sns|REJECT| |
|camel-aws2-sqs|REJECT| |
|camel-aws2-sts|REJECT| |
|camel-aws2-translate|REJECT| |
|camel-aws-cw|REJECT| |
|camel-aws-ddb|REJECT| |
|camel-aws-ec2|REJECT| |
|camel-aws-ecs|REJECT| |
|camel-aws-eks|REJECT| |
|camel-aws-iam|REJECT| |
|camel-aws-kinesis|REJECT| |
|camel-aws-kms|REJECT| |
|camel-aws-lambda|REJECT| |
|camel-aws-mq|REJECT| |
|camel-aws-msk|REJECT| |
|camel-aws-s3|REJECT| |
|camel-aws-sdb|REJECT| |
|camel-aws-ses|REJECT| |
|camel-aws-sns|REJECT| |
|camel-aws-sqs|REJECT| |
|camel-aws-swf|REJECT| |
|camel-aws-translate|REJECT| |
|camel-aws-xray|DONE| |
|camel-azure|DONE| |
|camel-azure-storage-blob| | |
|camel-azure-storage-queue| | |
|camel-barcode|DONE| |
|camel-base64|DONE| |
|camel-bean|DONE| |
|camel-beanio|DONE| |
|camel-beanstalk|REJECT|start a thread|
|camel-bean-validator|DONE| |
|camel-bindy|DONE| |
|camel-blueprint|DONE| |
|camel-bonita|DONE| |
|camel-boon|DONE| |
|camel-box|REJECT|network connection |
|camel-braintree|DONE| |
|camel-browse|DONE| |
|camel-cache|DONE| |
|camel-caffeine|REJECT|create thread pool|
|camel-cassandraql| | |
|camel-castor|DONE| |
|camel-cbor|DONE| |
|camel-cdi|REJECT|addConsumer should be in doStart|
|camel-chatscript|DONE| |
|camel-chronicle|DONE| |
|camel-chunk|REJECT|load theme folder from the disk|
|camel-cmis|DONE| |
|camel-cm-sms|REJECT|open network connection|
|camel-coap| | |
|camel-cometd| | |
|camel-consul| | |
|camel-context| | |
|camel-controlbus| | |
|camel-corda|REJECT|open network connection|
|camel-core-osgi| | |
|camel-core-xml| | |
|camel-couchbase| | |
|camel-couchdb| | |
|camel-cron| | |
|camel-crypto| | |
|camel-crypto-cms| | |
|camel-csv|DONE| |
|camel-cxf|REJECT|start a server|
|camel-cxf-transport| | |
|camel-dataformat|DONE| |
|camel-dataset|DONE| |
|camel-debezium| | |
|camel-debezium-common| | |
|camel-debezium-mongodb| | |
|camel-debezium-mysql| | |
|camel-debezium-postgres| | |
|camel-debezium-sqlserver| | |
|camel-digitalocean|REJECT|create a http client|
|camel-direct| | |
|camel-directvm| | |
|camel-disruptor|REJECT|start a thread|
|camel-djl| | |
|camel-dns| | |
|camel-docker| | |
|camel-dozer|DONE| |
|camel-drill| | |
|camel-dropbox| | |
|camel-eclipse| | |
|camel-ehcache| | |
|camel-ejb| | |
|camel-elasticsearch| | |
|camel-elasticsearch5| | |
|camel-elasticsearch-rest| | |
|camel-elsql|DONE| |
|camel-elytron| | |
|camel-etcd| | |
|camel-eventadmin| | |
|camel-exec| | |
|camel-facebook| | |
|camel-fastjson| | |
|camel-fhir| | |
|camel-file|DONE| |
|camel-file-watch| | |
|camel-flatpack| | |
|camel-flink|DONE| |
|camel-fop|DONE| |
|camel-freemarker| | |
|camel-ftp| | |
|camel-ganglia| | |
|camel-geocoder| | |
|camel-git| | |
|camel-github| | |
|camel-google-bigquery| | |
|camel-google-calendar| | |
|camel-google-drive| | |
|camel-google-mail| | |
|camel-google-pubsub| | |
|camel-google-sheets| | |
|camel-gora| | |
|camel-grape| | |
|camel-graphql| | |
|camel-grok| | |
|camel-groovy| | |
|camel-groovy-dsl| | |
|camel-grpc| | |
|camel-gson| | |
|camel-guava-eventbus| | |
|camel-guice| | |
|camel-hawtdb| | |
|camel-hazelcast| | |
|camel-hbase|DONE| |
|camel-hdfs| | |
|camel-hdfs2| | |
|camel-headersmap| | |
|camel-hessian| | |
|camel-hipchat| | |
|camel-hl7| | |
|camel-http| | |
|camel-http-base| | |
|camel-http-common| | |
|camel-hystrix| | |
|camel-ibatis| | |
|camel-ical| | |
|camel-iec60870| | |
|camel-ignite| | |
|camel-infinispan|REJECT|start a server and create thread |
|camel-influxdb| | |
|camel-iota| | |
|camel-ipfs| | |
|camel-irc| | |
|camel-ironmq| | |
|camel-jackson| | |
|camel-jacksonxml| | |
|camel-jasypt| | |
|camel-javaspace| | |
|camel-jaxb| | |
|camel-jbpm| | |
|camel-jcache| | |
|camel-jclouds| | |
|camel-jcr| | |
|camel-jdbc| | |
|camel-jetty| | |
|camel-jetty9| | |
|camel-jetty-common| | |
|camel-jgroups| | |
|camel-jgroups-raft| | |
|camel-jibx| | |
|camel-jing|DONE| |
|camel-jira|REJECT|create the http client |
|camel-jms|DONE| |
|camel-jmx| | |
|camel-johnzon| | |
|camel-jolt| | |
|camel-jooq| | |
|camel-josql| | |
|camel-jpa|DONE| |
|camel-jsch| | |
|camel-jslt| | |
|camel-jsonapi| | |
|camel-jsonata| | |
|camel-jsonpath| | |
|camel-json-validator| | |
|camel-jt400| | |
|camel-jta| | |
|camel-juel| | |
|camel-jxpath| | |
|camel-kafka| | |
|camel-kestrel| | |
|camel-krati| | |
|camel-kubernetes|REJECT|OKHttp client create thread pool |
|camel-kudu|REJECT|create thread pool|
|camel-kura| | |
|camel-language| | |
|camel-ldap| | |
|camel-ldif| | |
|camel-leveldb| | |
|camel-linkedin| | |
|camel-log|DONE| |
|camel-lra| | |
|camel-lucene| | |
|camel-lumberjack| | |
|camel-lzf| | |
|camel-mail| | |
|camel-master| | |
|camel-metrics| | |
|camel-micrometer| | |
|camel-microprofile-config| | |
|camel-microprofile-fault-tolerance| | |
|camel-microprofile-health| | |
|camel-microprofile-metrics| | |
|camel-milo| | |
|camel-mina| | |
|camel-mllp| | |
|camel-mock| | |
|camel-mongodb|REJECT| resolve the MongClient from the camelContext and it potentially open the connection and run the command |
|camel-mongodb-gridfs| | |
|camel-mqtt| | |
|camel-msv| | |
|camel-mustache| | |
|camel-mvel| | |
|camel-mybatis| | |
|camel-nagios| | |
|camel-nats| | |
|camel-netty| | |
|camel-netty-http|DONE| |
|camel-nitrite| | |
|camel-nsq| | |
|camel-ognl| | |
|camel-olingo2| | |
|camel-olingo4|REJECT|create the asyn http client |
|camel-openapi-java| | |
|camel-openshift| | |
|camel-openstack| | |
|camel-opentelemetry| | |
|camel-opentracing| | |
|camel-optaplanner| | |
|camel-osgi-activator| | |
|camel-paho| | |
|camel-paxlogging| | |
|camel-pdf| | |
|camel-pgevent| | |
|camel-pg-replication-slot| | |
|camel-platform-http|DONE| |
|camel-platform-http-vertx| | |
|camel-printer| | |
|camel-properties| | |
|camel-protobuf| | |
|camel-pubnub| | |
|camel-pulsar| | |
|camel-quartz|REJECT|quartz schedule create thread pool |
|camel-quickfix| | |
|camel-qute| | |
|camel-rabbitmq| | |
|camel-reactive-executor-vertx| | |
|camel-reactive-streams| | |
|camel-reactor| | |
|camel-ref|REJECT|add the other endpoint uri |
|camel-resilience4j| | |
|camel-rest| | |
|camel-resteasy| | |
|camel-restlet| | |
|camel-rest-openapi| | |
|camel-rest-swagger| | |
|camel-ribbon| | |
|camel-rmi| | |
|camel-robotframework| | |
|camel-routebox| | |
|camel-rss| | |
|camel-ruby| | |
|camel-rx| | |
|camel-rxjava| | |
|camel-rxjava2| | |
|camel-saga| | |
|camel-salesforce|REJECT|create a http client and start it |
|camel-sap-netweaver| | |
|camel-saxon| | |
|camel-scala| | |
|camel-scheduler| | |
|camel-schematron| | |
|camel-scr| | |
|camel-script| | |
|camel-seda|DONE| |
|camel-service| | |
|camel-servicenow| | |
|camel-servlet| | |
|camel-servletlistener| | |
|camel-shiro| | |
|camel-sip| | |
|camel-sjms|REJECT|create connections pool |
|camel-slack| | |
|camel-smpp| | |
|camel-snakeyaml| | |
|camel-snmp| | |
|camel-soap| | |
|camel-solr| | |
|camel-soroush| | |
|camel-spark| | |
|camel-spark-rest| | |
|camel-splunk| | |
|camel-splunk-hec| | |
|camel-spring| | |
|camel-spring-batch| | |
|camel-spring-boot| | |
|camel-spring-cloud| | |
|camel-spring-cloud-consul| | |
|camel-spring-cloud-netflix| | |
|camel-spring-cloud-zookeeper| | |
|camel-spring-integration| | |
|camel-spring-javaconfig| | |
|camel-spring-ldap| | |
|camel-spring-main| | |
|camel-spring-redis| | |
|camel-spring-security| | |
|camel-spring-ws| | |
|camel-sql|DONE| |
|camel-ssh| | |
|camel-stax| | |
|camel-stomp| | |
|camel-stream|DONE| |
|camel-stringtemplate| | |
|camel-stub| | |
|camel-swagger| | |
|camel-swagger-java| | |
|camel-syslog| | |
|camel-tagsoup| | |
|camel-tarfile| | |
|camel-telegram|REJECT|create thread pool |
|camel-test| | |
|camel-test-blueprint| | |
|camel-test-cdi| | |
|camel-testcontainers| | |
|camel-testcontainers-junit5| | |
|camel-testcontainers-spring| | |
|camel-testcontainers-spring-junit5| | |
|camel-test-junit5| | |
|camel-test-karaf| | |
|camel-testng| | |
|camel-test-spring| | |
|camel-test-spring-junit5| | |
|camel-threadpoolfactory-vertx| | |
|camel-thrift| | |
|camel-tika| | |
|camel-timer|DONE| |
|camel-tracing| | |
|camel-twilio| | |
|camel-twitter| | |
|camel-undertow| | |
|camel-undertow-spring-security| | |
|camel-univocity-parsers| | |
|camel-urlrewrite| | |
|camel-validator| | |
|camel-velocity| | |
|camel-vertx| | |
|camel-vertx-http| | |
|camel-vertx-websocket| | |
|camel-vm| | |
|camel-weather| | |
|camel-web3j| | |
|camel-webhook| | |
|camel-websocket| | |
|camel-websocket-jsr356| | |
|camel-weka| | |
|camel-wordpress| | |
|camel-workday| | |
|camel-xchange| | |
|camel-xj| | |
|camel-xmlbeans| | |
|camel-xmlrpc| | |
|camel-xmlsecurity| | |
|camel-xmpp| | |
|camel-xpath| | |
|camel-xslt|DONE| |
|camel-xslt-saxon| | |
|camel-xstream| | |
|camel-yammer| | |
|camel-zendesk| | |
|camel-zip-deflater| | |
|camel-zipfile| | |
|camel-zipkin| | |
|camel-zookeeper| | |
|camel-zookeeper-master| | |

==> apache-camel-3.6.0-src.zip: apache-camel-3.6.0/components/components-init-work-in-progress.md <==
# This is used to track the work of [CAMEL-14805 ](https://issues.apache.org/jira/browse/CAMEL-14805) and [CAMEL-15176](https://issues.apache.org/jira/browse/CAMEL-15176)

| component | status | reason |
|   ---- | ---- | ---- |
|camel-activemq|DONE| |
|camel-ahc|REJECT|create thread pool|
|camel-ahc-ws|REJECT|open network connection|
|camel-amqp|DONE| |
|camel-any23|DONE| |
|camel-apns|REJECT|add the consumer should be in doStart |
|camel-arangodb|REJECT|open network connection to resolve host server|
|camel-as2|REJECT| |
|camel-asn1|DONE| |
|camel-asterisk|DONE| |
|camel-atmos|REJECT | |
|camel-atmosphere-websocket|DONE| |
|camel-atom|DONE| |
|camel-atomix|DONE| |
|camel-attachments|DONE| |
|camel-avro|DONE| |
|camel-avro-rpc|REJECT|start a server|
|camel-aws|DONE| |
|camel-aws2-athena|DONE| |
|camel-aws2-cw|DONE| |
|camel-aws2-ddb|REJECT| |
|camel-aws2-ec2|REJECT| |
|camel-aws2-ecs|REJECT| |
|camel-aws2-eks|REJECT| |
|camel-aws2-iam|REJECT| |
|camel-aws2-kinesis|REJECT| |
|camel-aws2-kms|REJECT| |
|camel-aws2-lambda|REJECT| |
|camel-aws2-mq|REJECT| |
|camel-aws2-msk|REJECT| |
|camel-aws2-s3|REJECT| |
|camel-aws2-ses|REJECT| |
|camel-aws2-sns|REJECT| |
|camel-aws2-sqs|REJECT| |
|camel-aws2-sts|REJECT| |
|camel-aws2-translate|REJECT| |
|camel-aws-cw|REJECT| |
|camel-aws-ddb|REJECT| |
|camel-aws-ec2|REJECT| |
|camel-aws-ecs|REJECT| |
|camel-aws-eks|REJECT| |
|camel-aws-iam|REJECT| |
|camel-aws-kinesis|REJECT| |
|camel-aws-kms|REJECT| |
|camel-aws-lambda|REJECT| |
|camel-aws-mq|REJECT| |
|camel-aws-msk|REJECT| |
|camel-aws-s3|REJECT| |
|camel-aws-sdb|REJECT| |
|camel-aws-ses|REJECT| |
|camel-aws-sns|REJECT| |
|camel-aws-sqs|REJECT| |
|camel-aws-swf|REJECT| |
|camel-aws-translate|REJECT| |
|camel-aws-xray|DONE| |
|camel-azure|DONE| |
|camel-azure-storage-blob| | |
|camel-azure-storage-queue| | |
|camel-barcode|DONE| |
|camel-base64|DONE| |
|camel-bean|DONE| |
|camel-beanio|DONE| |
|camel-beanstalk|REJECT|start a thread|
|camel-bean-validator|DONE| |
|camel-bindy|DONE| |
|camel-blueprint|DONE| |
|camel-bonita|DONE| |
|camel-boon|DONE| |
|camel-box|REJECT|network connection |
|camel-braintree|DONE| |
|camel-browse|DONE| |
|camel-cache|DONE| |
|camel-caffeine|REJECT|create thread pool|
|camel-cassandraql|REJECT | |
|camel-castor|DONE| |
|camel-cbor|DONE| |
|camel-cdi|REJECT|addConsumer should be in doStart|
|camel-chatscript|DONE| |
|camel-chronicle|DONE| |
|camel-chunk|REJECT|load theme folder from the disk|
|camel-cmis|DONE| |
|camel-cm-sms|REJECT|open network connection|
|camel-coap|REJECT | |
|camel-cometd| | |
|camel-consul| | |
|camel-context| | |
|camel-controlbus| | |
|camel-corda|REJECT|open network connection|
|camel-core-osgi| | |
|camel-core-xml| | |
|camel-couchbase| | |
|camel-couchdb| | |
|camel-cron| | |
|camel-crypto| | |
|camel-crypto-cms| | |
|camel-csv|DONE| |
|camel-cxf|REJECT|start a server|
|camel-cxf-transport| | |
|camel-dataformat|DONE| |
|camel-dataset|DONE| |
|camel-debezium| | |
|camel-debezium-common| | |
|camel-debezium-mongodb| | |
|camel-debezium-mysql| | |
|camel-debezium-postgres| | |
|camel-debezium-sqlserver| | |
|camel-digitalocean|REJECT|create a http client|
|camel-direct| | |
|camel-directvm| | |
|camel-disruptor|REJECT|start a thread|
|camel-djl| | |
|camel-dns| | |
|camel-docker| | |
|camel-dozer|DONE| |
|camel-drill| | |
|camel-dropbox| | |
|camel-eclipse| | |
|camel-ehcache| | |
|camel-ejb| | |
|camel-elasticsearch| | |
|camel-elasticsearch5| | |
|camel-elasticsearch-rest| | |
|camel-elsql|DONE| |
|camel-elytron| | |
|camel-etcd| | |
|camel-eventadmin| | |
|camel-exec| | |
|camel-facebook| | |
|camel-fastjson| | |
|camel-fhir| | |
|camel-file|DONE| |
|camel-file-watch| | |
|camel-flatpack| | |
|camel-flink|DONE| |
|camel-fop|DONE| |
|camel-freemarker| | |
|camel-ftp| | |
|camel-ganglia| | |
|camel-geocoder| | |
|camel-git| | |
|camel-github| | |
|camel-google-bigquery| | |
|camel-google-calendar| | |
|camel-google-drive| | |
|camel-google-mail| | |
|camel-google-pubsub| | |
|camel-google-sheets| | |
|camel-gora| | |
|camel-grape| | |
|camel-graphql| | |
|camel-grok| | |
|camel-groovy| | |
|camel-groovy-dsl| | |
|camel-grpc| | |
|camel-gson| | |
|camel-guava-eventbus| | |
|camel-guice| | |
|camel-hawtdb| | |
|camel-hazelcast| | |
|camel-hbase|DONE| |
|camel-hdfs| | |
|camel-hdfs2| | |
|camel-headersmap| | |
|camel-hessian| | |
|camel-hl7| | |
|camel-http| | |
|camel-http-base| | |
|camel-http-common| | |
|camel-hystrix| | |
|camel-ibatis| | |
|camel-ical| | |
|camel-iec60870| | |
|camel-ignite| | |
|camel-infinispan|REJECT|start a server and create thread |
|camel-influxdb| | |
|camel-iota| | |
|camel-ipfs| | |
|camel-irc| | |
|camel-ironmq| | |
|camel-jackson| | |
|camel-jacksonxml| | |
|camel-jasypt| | |
|camel-javaspace| | |
|camel-jaxb| | |
|camel-jbpm| | |
|camel-jcache| | |
|camel-jclouds| | |
|camel-jcr| | |
|camel-jdbc| | |
|camel-jetty| | |
|camel-jetty9| | |
|camel-jetty-common| | |
|camel-jgroups| | |
|camel-jgroups-raft| | |
|camel-jibx| | |
|camel-jing|DONE| |
|camel-jira|REJECT|create the http client |
|camel-jms|DONE| |
|camel-jmx| | |
|camel-johnzon| | |
|camel-jolt| | |
|camel-jooq| | |
|camel-josql| | |
|camel-jpa|DONE| |
|camel-jsch| | |
|camel-jslt| | |
|camel-jsonapi| | |
|camel-jsonata| | |
|camel-jsonpath| | |
|camel-json-validator| | |
|camel-jt400| | |
|camel-jta| | |
|camel-juel| | |
|camel-jxpath| | |
|camel-kafka| | |
|camel-kestrel| | |
|camel-krati| | |
|camel-kubernetes|REJECT|OKHttp client create thread pool |
|camel-kudu|REJECT|create thread pool|
|camel-kura| | |
|camel-language| | |
|camel-ldap| | |
|camel-ldif| | |
|camel-leveldb| | |
|camel-linkedin| | |
|camel-log|DONE| |
|camel-lra| | |
|camel-lucene| | |
|camel-lumberjack| | |
|camel-lzf| | |
|camel-mail| | |
|camel-master| | |
|camel-metrics| | |
|camel-micrometer| | |
|camel-microprofile-config| | |
|camel-microprofile-fault-tolerance| | |
|camel-microprofile-health| | |
|camel-microprofile-metrics| | |
|camel-milo| | |
|camel-mina| | |
|camel-mllp| | |
|camel-mock| | |
|camel-mongodb|REJECT| resolve the MongClient from the camelContext and it potentially open the connection and run the command |
|camel-mongodb-gridfs| | |
|camel-mqtt| | |
|camel-msv| | |
|camel-mustache| | |
|camel-mvel| | |
|camel-mybatis| | |
|camel-nagios| | |
|camel-nats| | |
|camel-netty| | |
|camel-netty-http|DONE| |
|camel-nitrite| | |
|camel-nsq| | |
|camel-ognl| | |
|camel-olingo2| | |
|camel-olingo4|REJECT|create the asyn http client |
|camel-openapi-java| | |
|camel-openshift| | |
|camel-openstack| | |
|camel-opentelemetry| | |
|camel-opentracing| | |
|camel-optaplanner| | |
|camel-osgi-activator| | |
|camel-paho| | |
|camel-paxlogging| | |
|camel-pdf| | |
|camel-pgevent| | |
|camel-pg-replication-slot| | |
|camel-platform-http|DONE| |
|camel-platform-http-vertx|DONE | |
|camel-printer| | |
|camel-properties| | |
|camel-protobuf| | |
|camel-pubnub| | |
|camel-pulsar| | |
|camel-quartz|REJECT|quartz schedule create thread pool |
|camel-quickfix| | |
|camel-qute| | |
|camel-rabbitmq| | |
|camel-reactive-executor-vertx| | |
|camel-reactive-streams| | |
|camel-reactor| | |
|camel-ref|REJECT|add the other endpoint uri |
|camel-resilience4j| | |
|camel-rest| | |
|camel-resteasy| | |
|camel-restlet| | |
|camel-rest-openapi| | |
|camel-rest-swagger| | |
|camel-ribbon| | |
|camel-rmi| | |
|camel-robotframework| | |
|camel-routebox| | |
|camel-rss| | |
|camel-ruby| | |
|camel-rx| | |
|camel-rxjava| | |
|camel-rxjava2| | |
|camel-saga| | |
|camel-salesforce|REJECT|create a http client and start it |
|camel-sap-netweaver| | |
|camel-saxon| | |
|camel-scala| | |
|camel-scheduler| | |
|camel-schematron| | |
|camel-scr| | |
|camel-script| | |
|camel-seda|DONE| |
|camel-service| | |
|camel-servicenow| | |
|camel-servlet| | |
|camel-servletlistener| | |
|camel-shiro| | |
|camel-sip| | |
|camel-sjms|REJECT|create connections pool |
|camel-slack| | |
|camel-smpp| | |
|camel-snakeyaml| | |
|camel-snmp| | |
|camel-soap| | |
|camel-solr| | |
|camel-soroush| | |
|camel-spark| | |
|camel-spark-rest| | |
|camel-splunk| | |
|camel-splunk-hec| | |
|camel-spring| | |
|camel-spring-batch| | |
|camel-spring-boot| | |
|camel-spring-cloud| | |
|camel-spring-cloud-consul| | |
|camel-spring-cloud-netflix| | |
|camel-spring-cloud-zookeeper| | |
|camel-spring-integration| | |
|camel-spring-javaconfig| | |
|camel-spring-ldap| | |
|camel-spring-main| | |
|camel-spring-redis| | |
|camel-spring-security| | |
|camel-spring-ws| | |
|camel-sql|DONE| |
|camel-ssh| | |
|camel-stax|DONE | |
|camel-stomp| | |
|camel-stream|DONE| |
|camel-stringtemplate| | |
|camel-stub| | |
|camel-swagger| | |
|camel-swagger-java| | |
|camel-syslog| | |
|camel-tagsoup| | |
|camel-tarfile| | |
|camel-telegram|REJECT|create thread pool |
|camel-test| | |
|camel-test-blueprint| | |
|camel-test-cdi| | |
|camel-testcontainers| | |
|camel-testcontainers-junit5| | |
|camel-testcontainers-spring| | |
|camel-testcontainers-spring-junit5| | |
|camel-test-junit5| | |
|camel-test-karaf| | |
|camel-testng| | |
|camel-test-spring| | |
|camel-test-spring-junit5| | |
|camel-threadpoolfactory-vertx|DONE | |
|camel-thrift| | |
|camel-tika| | |
|camel-timer|DONE| |
|camel-tracing| | |
|camel-twilio| | |
|camel-twitter| | |
|camel-undertow| | |
|camel-undertow-spring-security| | |
|camel-univocity-parsers| | |
|camel-urlrewrite| | |
|camel-validator| | |
|camel-velocity| | |
|camel-vertx|DONE | |
|camel-vertx-http|DONE | |
|camel-vertx-websocket|DONE | |
|camel-vm| | |
|camel-weather| | |
|camel-web3j| | |
|camel-webhook| | |
|camel-websocket| | |
|camel-websocket-jsr356| | |
|camel-weka| | |
|camel-wordpress| | |
|camel-workday| | |
|camel-xchange| | |
|camel-xj| | |
|camel-xmlbeans| | |
|camel-xmlrpc| | |
|camel-xmlsecurity| | |
|camel-xmpp| | |
|camel-xpath|DONE | |
|camel-xslt|DONE| |
|camel-xslt-saxon|DONE | |
|camel-xstream| | |
|camel-yammer| | |
|camel-zendesk| | |
|camel-zip-deflater| | |
|camel-zipfile| | |
|camel-zipkin| | |
|camel-zookeeper| | |
|camel-zookeeper-master| | |
